@@ -9,8 +9,7 @@ from dulwich import index
 from dulwich import porcelain
 from dulwich.client import HTTPUnauthorized
 from dulwich.repo import Repo as DulwichRepo
-from mirutil.tok import get_local_toks_js_fp as gltfp
-from mirutil.tok import get_val_by_key_fr_json as gvkfj
+from mtok import get_token as gettoken
 from purl import URL
 
 
@@ -23,7 +22,6 @@ class GitHubRepo :
                  local_path = None ,
                  committing_usr: (str , None) = None ,
                  token: (str , None) = None) :
-
         self.local_path = local_path
         self.committing_usr = committing_usr
         self.token = token
@@ -34,8 +32,7 @@ class GitHubRepo :
         self.repo_name = self.u.path_segment(1)
         self.usr_repo = self.usr + '/' + self.repo_name
 
-        # noinspection PyTypeChecker
-        self.repo: DulwichRepo = None
+        self.repo: DulwichRepo | None = None
 
         self.cred_usr = None
         self.cred_tok = None
@@ -47,6 +44,34 @@ class GitHubRepo :
         if self.local_path is None :
             self.local_path = Path(self.repo_name)
 
+    def _set_cred_usr_tok(self) :
+        cu = self.committing_usr
+        tok = self.token
+        if (cu is not None) and (tok is not None) :
+            self.cred_usr , self.cred_tok = cu , tok
+            return
+        if cu is not None :
+            self.cred_usr , self.cred_tok = gettoken(cu)
+            return
+        self.cred_usr , self.cred_tok = gettoken(self.usr)
+
+    def _set_cred_url(self) :
+        self._set_cred_usr_tok()
+        self.cred_url = ret_github_url_wt_credentials(self.cred_usr ,
+                                                      self.cred_tok ,
+                                                      self.usr ,
+                                                      self.repo)
+
+    def _stage_all_changes(self) :
+        idx = self.repo.open_index()
+        lp = str(self.local_path) + '/'
+        fu = porcelain.get_untracked_paths
+        untracked = fu(lp , lp , idx , exclude_ignored = True)
+        unstaged = index.get_unstaged_changes(idx , self.local_path)
+        all_changes = list(unstaged) + list(untracked)
+        self.repo.stage(all_changes)
+        return all_changes
+
     def clone_overwrite(self , depth = 1) :
         """ Every time excecuted, it re-downloads last version of the reposiroty to local_path.
 
@@ -54,66 +79,19 @@ class GitHubRepo :
         return: None
         """
         self.rmdir()
-
         dirr = self.local_path
-
         try :
             self.repo = porcelain.clone(str(self.u) , dirr , depth = depth)
-
         except HTTPUnauthorized :
             self._set_cred_url()
             self.repo = porcelain.clone(self.cred_url , dirr , depth = depth)
 
-    def _set_cred_url(self) :
-        self._set_cred_usr_tok()
-        cu = self.cred_usr
-        ct = self.cred_tok
-        tu = self.usr
-        tr = self.repo_name
-        self.cred_url = ret_github_url_wt_credentials(cu , ct , tu , tr)
-
-    def _set_cred_usr_tok(self) :
-        cu = self.committing_usr
-        tok = self.token
-        if (cu is not None) and (tok is not None) :
-            self.cred_usr , self.cred_tok = cu , tok
-            return
-
-        fp = gltfp()
-        if cu is not None :
-            self._set_cred_usr_tok_fr_file(fp , github_usr = cu)
-            return
-
-        self._set_cred_usr_tok_fr_file(fp , github_usr = self.usr)
-
-    def _set_cred_usr_tok_fr_file(self , fp , github_usr = None) :
-        o = gvkfj(fp , key = github_usr)
-        self.cred_usr , self.cred_tok = o.key , o.val
-
-    def _stage_all_changes(self) :
-        idx = self.repo.open_index()
-
-        lp = str(self.local_path) + '/'
-        fu = porcelain.get_untracked_paths
-        untracked = fu(lp , lp , idx , exclude_ignored = True)
-
-        unstaged = index.get_unstaged_changes(idx , self.local_path)
-
-        all_changes = list(unstaged) + list(untracked)
-
-        self.repo.stage(all_changes)
-
-        return all_changes
-
     def commit_and_push(self , commit_msg , branch = 'main') :
         if self.cred_url is None :
             self._set_cred_url()
-
         self._stage_all_changes()
-
         bmsg = commit_msg.encode()
         self.repo.do_commit(bmsg)
-
         porcelain.push(str(self.local_path) , self.cred_url , branch)
         print(commit_msg)
 
